@@ -44,6 +44,16 @@ func (ef *ExperimentalFeatures) SetCompositeEmbedders(enable bool) *Experimental
 	return ef
 }
 
+func (ef *ExperimentalFeatures) SetChatCompletions(enable bool) *ExperimentalFeatures {
+	ef.ChatCompletions = &enable
+	return ef
+}
+
+func (ef *ExperimentalFeatures) SetMultiModal(enable bool) *ExperimentalFeatures {
+	ef.MultiModal = &enable
+	return ef
+}
+
 func (ef *ExperimentalFeatures) Get() (*ExperimentalFeaturesResult, error) {
 	return ef.GetWithContext(context.Background())
 }
@@ -79,6 +89,8 @@ func (ef *ExperimentalFeatures) UpdateWithContext(ctx context.Context) (*Experim
 		ContainsFilter:          ef.ContainsFilter,
 		Network:                 ef.Network,
 		CompositeEmbedders:      ef.CompositeEmbedders,
+		ChatCompletions:         ef.ChatCompletions,
+		MultiModal:              ef.MultiModal,
 	}
 	resp := new(ExperimentalFeaturesResult)
 	req := &internalRequest{
