@@ -122,6 +122,14 @@ func cleanupWebhook(services ...meilisearch.WebhookManager) func() {
 	}
 }
 
+func cleanupNetwork(services ...meilisearch.ServiceManager) func() {
+	return func() {
+		for _, s := range services {
+			_, _ = resetNetwork(s)
+		}
+	}
+}
+
 func getPrivateKey(sv meilisearch.ServiceManager) (key string) {
 	list, err := sv.GetKeys(nil)
 	if err != nil {
@@ -165,6 +173,17 @@ func deleteAllIndexes(sv meilisearch.ServiceManager) (ok bool, err error) {
 	return true, nil
 }
 
+func resetNetwork(sv meilisearch.ServiceManager) (ok bool, err error) {
+	_, err = sv.UpdateNetwork(&meilisearch.Network{
+		Self:    meilisearch.Null[string](),
+		Remotes: meilisearch.Null[map[string]meilisearch.Opt[meilisearch.Remote]](),
+	})
+	if err != nil {
+		return false, err
+	}
+	return true, nil
+}
+
 func deleteAllWebhooks(webhookMgr meilisearch.WebhookManager) (ok bool, err error) {
 	list, err := webhookMgr.ListWebhooks()
 	if err != nil {
