@@ -77,6 +77,14 @@ func (m *meilisearch) KeyReader() KeyReader {
 	return m
 }
 
+func (m *meilisearch) WebhookManager() WebhookManager { return m }
+
+func (m *meilisearch) WebhookReader() WebhookReader { return m }
+
+func (m *meilisearch) ChatManager() ChatManager { return m }
+
+func (m *meilisearch) ChatReader() ChatReader { return m }
+
 func (m *meilisearch) Index(uid string) IndexManager {
 	return newIndex(m.client, uid)
 }
@@ -733,6 +741,28 @@ func (m *meilisearch) GetBatchWithContext(ctx context.Context, batchUID int) (*B
 	return resp, nil
 }
 
+func (m *meilisearch) Export(param *ExportParams) (*TaskInfo, error) {
+	return m.ExportWithContext(context.Background(), param)
+}
+
+func (m *meilisearch) ExportWithContext(ctx context.Context, param *ExportParams) (*TaskInfo, error) {
+	resp := new(TaskInfo)
+	req := &internalRequest{
+		endpoint:            "/export",
+		method:              http.MethodPost,
+		withRequest:         param,
+		contentType:         contentTypeJSON,
+		withResponse:        resp,
+		withQueryParams:     map[string]string{},
+		acceptedStatusCodes: []int{http.StatusOK, http.StatusAccepted},
+		functionName:        "Export",
+	}
+	if err := m.client.executeRequest(ctx, req); err != nil {
+		return nil, err
+	}
+	return resp, nil
+}
+
 func getTask(ctx context.Context, cli *client, taskUID int64) (*Task, error) {
 	resp := new(Task)
 	req := &internalRequest{
